from setuptools import setup, find_packages

setup(
    name='lins_cieloApi3',
    version='0.1.0', 
    description='Pacote customizado da sdk python da cielo, https://github.com/DeveloperCielo/API-3.0-Python',
    url='https://lpsvn.lojaspompeia.com.br/svn/pypck-lins_cieloApi3/',
    author='Halyson Sampaio',
    author_email='halyson@lojaspompeia.com.br',
    packages=find_packages(),
    zip_safe=False
)